# Contributing to Enatega Multi Vendor Food Delivery System

First off, thank you for considering contributing to our project! Your help is greatly appreciated.

## How Can I Contribute?

### Reporting Bugs

If you find a bug in the project, please submit an issue. When reporting a bug, please include:

- A clear and descriptive title.
- A detailed description of the problem, including steps to reproduce.
- Any relevant logs, screenshots, or other information that could help diagnose the problem.

### Suggesting Enhancements

We welcome suggestions for improvements and new features. When suggesting an enhancement, please include:

- A clear and descriptive title.
- A detailed description of the proposed change.
- Any relevant context or reasoning for the enhancement.

### Pull Requests

If you would like to contribute code, follow these steps:

1. **Fork the repository**: Create a fork of the repository on GitHub.
2. **Clone your fork**: Clone your fork to your local machine.
    ```bash
    git clone https://github.com/<your-username>/food-delivery-multivendor.git
    cd food-delivery-multivendor
    ```
3. **Create a new branch**: Create a new branch for your feature or bugfix.
    ```bash
    git checkout -b feature-or-bugfix-description
    ```
4. **Make your changes**: Make your changes to the code.
5. **Test your changes**: Ensure your changes work as expected and do not introduce any issues.
6. **Commit your changes**: Commit your changes with a descriptive commit message.
    ```bash
    git add .
    git commit -m "Description of the feature or bugfix"
    ```
7. **Push your changes**: Push your changes to your fork.
    ```bash
    git push origin feature-or-bugfix-description
    ```
8. **Submit a pull request**: Create a pull request from your fork to the main repository. Include a detailed description of your changes.

### Coding Guidelines

To ensure consistency in the codebase, please follow these guidelines:

- **Code Style**: Follow the existing code style in the project.
- **Comments**: Write clear and concise comments for complex code sections.
- **Tests**: Write tests for new features and bug fixes.

### Code of Conduct

By participating in this project, you agree to abide by our [Code of Conduct](CODE_OF_CONDUCT.md).

## Getting Started

### Prerequisites

Ensure you have the following installed:

- Node.js (version 14.0 to 16.0)
- npm or yarn

### Setting Up

1. **Clone the repository**:
    ```bash
    git clone https://github.com/enatega/food-delivery-multivendor.git
    cd food-delivery-multivendor
    ```

2. **Install dependencies**:
    ```bash
    npm install
    # or
    yarn install
    ```

3. **Run the development server**:
    ```bash
    npm start
    # or
    yarn start
    ```
